@@ -1,7 +1,3 @@
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
-#include <stdint.h>
 #include <cmocka.h>
 
 /* A test case that does nothing and succeeds. */
