@@ -14,13 +14,8 @@
  * limitations under the License.
  */
 
-/* Use the unit test allocators */
-#define UNIT_TESTING 1
+#include <stdlib.h>
 
-#include <stdarg.h>
-#include <stddef.h>
-#include <stdint.h>
-#include <setjmp.h>
 #include <cmocka.h>
 
 static int setup(void **state) {
