@@ -1,6 +1,3 @@
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
 #include <cmocka.h>
 
 #include <signal.h>
