@@ -1,9 +1,5 @@
-#define UNIT_TESTING 1
+#include <stdlib.h>
 
-#include <stdarg.h>
-#include <stddef.h>
-#include <stdint.h>
-#include <setjmp.h>
 #include <cmocka.h>
 
 static int setup_fail(void **state) {
