@@ -14,9 +14,6 @@
  * limitations under the License.
  */
 
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
 #include <cmocka.h>
 
 /* A test case that does check if an int is equal. */
